@@ -1,3 +1,20 @@
+/* Copyright (C) 1999-2001 Free Software Foundation, Inc.
+   This file is part of the GNU LIBICONV Tools.
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+
 /*
  * Generates a CJK character set table from a .TXT table as found on
  * ftp.unicode.org or in the X nls directory.
@@ -53,6 +70,25 @@ typedef struct {
  */
 static void output_title (const char *charsetname)
 {
+  printf("/*\n");
+  printf(" * Copyright (C) 1999-2001 Free Software Foundation, Inc.\n");
+  printf(" * This file is part of the GNU LIBICONV Library.\n");
+  printf(" *\n");
+  printf(" * The GNU LIBICONV Library is free software; you can redistribute it\n");
+  printf(" * and/or modify it under the terms of the GNU Library General Public\n");
+  printf(" * License as published by the Free Software Foundation; either version 2\n");
+  printf(" * of the License, or (at your option) any later version.\n");
+  printf(" *\n");
+  printf(" * The GNU LIBICONV Library is distributed in the hope that it will be\n");
+  printf(" * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of\n");
+  printf(" * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU\n");
+  printf(" * Library General Public License for more details.\n");
+  printf(" *\n");
+  printf(" * You should have received a copy of the GNU Library General Public\n");
+  printf(" * License along with the GNU LIBICONV Library; see the file COPYING.LIB.\n");
+  printf(" * If not, write to the Free Software Foundation, Inc., 59 Temple Place -\n");
+  printf(" * Suite 330, Boston, MA 02111-1307, USA.\n");
+  printf(" */\n");
   printf("\n");
   printf("/*\n");
   printf(" * %s\n", charsetname);
